<?php

namespace Ems\Logic\ProcessamentoSolicitacao;

use Ems\Util\Utils;
use Util\{ DateUtil, NovoCodigo, Repositories };

class ProcessamentoSolicitacaoRemanejamento extends ProcessamentoSolicitacao {
    
    public function efetivar() {
        $itens = $this->getItensAssociativeArray();
        
        $nrorg          = Utils::getParamters()->getNrorg();
        $nrvinculom     = $this->getSolicitacao()->getNrvinculom();
        $dtcompetencia  = DateUtil::getDataDeString(Utils::getParamters()->getDtmescomptencDiaCorrente(),DateUtil::FORMATO_BRASILEIRO,true);
        
        $paramOrg = Utils::getEntityManager()->getRepository(Repositories::GPE_PARAMORG)->findOneBy(['nrorg' => $nrorg]);
        $nrtipoestrutlegal = !empty($paramOrg) ? $paramOrg->getNrtpestrutlegal() : null;
        
        $nrtipotransfer = $itens['NRTIPOTRANSFER']  ?? null;
        $nrtpmovtransfm = $itens['NRTPMOVTRANSFM']  ?? null;
        $nrmotivotransf = $itens['NRMOTIVOTRANSF']  ?? null;
        $nrestruturam   = $itens['NRESTRUTURAM']    ?? null;
        $dtinimoviment  = isset($itens['DTINIMOVIMENT']) ? DateUtil::getDataDeString(substr($itens['DTINIMOVIMENT'],0,10), DateUtil::FORMATO_BRASILEIRO, true) : null;
        $dtfimmoviment  = isset($itens['DTFIMMOVIMENT']) ? DateUtil::getDataDeString(substr($itens['DTFIMMOVIMENT'],0,10), DateUtil::FORMATO_BRASILEIRO, true) : null;
    
        $estrutura_nova = Utils::getEntityManager()->getRepository(Repositories::ESTRUTURAM)->findOneBy(array("nrorg"=> $nrorg,"nrestruturam" => $nrestruturam));
        $result = Utils::getEntityManager()->getRepository(Repositories::GPE_MOVIMENTACAO)->findBy(array("nrorg"=> $nrorg,"nrvinculom" => $nrvinculom,"dtinimoviment" => $dtinimoviment));

        if($result){
            $estrutura_historico = Utils::getEntityManager()->getRepository(Repositories::ESTRUTURAM)->findBy(array("nrorg"=> $nrorg,"nrestruturam" => $result->getNrestruturam()));
            if($estrutura_historico->getNrtipoestrutura() == $estrutura_nova->getNrtipoestrutura())
                throw new \Exception("Já existe uma movimentação para este tipo de estrutura nesta data");
        }
        if($nrtipotransfer == 1){
            if($estrutura_nova->getNrtipoestrutura() != $nrtipoestrutlegal && $estrutura_nova->getNrtipoestrutura() != 10)
                throw new \Exception("A nova estrutura legal deve ser do mesmo tipo que a antiga.");
        }
        else if($estrutura_nova->getNrtipoestrutura() == $nrtipoestrutlegal)
                throw new \Exception("A nova estrutura legal deve ser de tipo diferente que a antiga.");
        
        if(DateUtil::comparaDatas($dtcompetencia,$dtinimoviment, DateUtil::DEPOIS)){
                throw new \Exception("A movimentação não pode ser retroativa");
        }

        //throw new \Exception("Já existe uma alteração de ocupação para este vinculo nesta data");
        
        $gpeMovimentacao = Repositories::GPE_MOVIMENTACAO;
        $movimentacao = new $gpeMovimentacao;
        $movimentacao->setNrorg($nrorg);
        $movimentacao->setNrvinculom($nrvinculom);
        $movimentacao->setNrtipoestrutura($estrutura_nova->getNrtipoestrutura());
        $movimentacao->setNrestruturam($nrestruturam);
        $movimentacao->setNrmotivotransf($nrmotivotransf);
        $movimentacao->setNrtipotransfer($nrtipotransfer);
        $movimentacao->setNrtpmovtransfm($nrtpmovtransfm);
        $movimentacao->setDtfimmoviment($dtfimmoviment);
        $movimentacao->setDtinimoviment($dtinimoviment);
        $movimentacao->setDtinclusao(DateUtil::getDataAtual(false));
        $movimentacao->setNrorginclusao(Utils::getParamters()->getNrorg());
        $movimentacao->setCdoperinclusao(Utils::getParamters()->getCdoperador());
        $movimentacao->setNrmovimentacao(NovoCodigo::geraCodigo(Utils::getParamters()->getNrorg(), 'GPE_MOVIMENTACAO', 1, 12, true));
        Utils::getEntityManager()->persist($movimentacao);
        Utils::getEntityManager()->flush();
        
        $vinc = ProcessamentoSolicitacaoUtil::retornaUltimoHistoricoVinculoCompetencia($nrorg, $nrvinculom, $dtcompetencia);
        if($vinc->getDtmescompetenc() == $dtcompetencia){
            $vinc->setDtultatu(DateUtil::getDataAtual());
            $vinc->setNrorgultatu(Utils::getParamters()->getNrorg());
            $vinc->setCdoperultatu(Utils::getParamters()->getCdoperador());
            if($nrtipotransfer == 1)
                $vinc->setNrestrutlegal($nrestruturam);
            else 
                $vinc->setNrestrutgeren($nrestruturam);
            Utils::getEntityManager()->persist($vinc);
            Utils::getEntityManager()->flush();
        }
        else
        ProcessamentoSolicitacaoUtil::novoHistoricoVinculo($nrorg, $nrvinculom, $dtcompetencia, $vinc->getNrsitufuncm(), $vinc->getNrcargo(), $vinc->getNrescalatrabm(),
            $vinc->getIdcontribuisind(), $vinc->getNrdependir(), $vinc->getNrdependsfam(), $vinc->getDtbaseferias(), $vinc->getIdremuneracao(),
            $vinc->getIdtppagamento(), (($nrtipotransfer == 1)?$nrestruturam:$vinc->getNrestrutlegal()),(($nrtipotransfer == 1)?$vinc->getNrestrutgeren():$nrestruturam) , $vinc->getNrtpmodalidsal(), $vinc->getIdmultvinc(),
            $vinc->getNrfuncao(), $vinc->getCdcontribindividual(), $vinc->getNrtpmovtransfm(), $vinc->getDtfimcontrdetermin(),
            $vinc->getNrestrutsind(), $vinc->getConfidencial()
        );
    }
    
    public function rejeitar() {}
}