<?php

namespace Ems\Repository;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;

class TreinamentoRepository {
    /** @var Connection */
    protected $connection;

    public function __construct(
        EntityManager $entityManager
    ) {
        $this->entityManager = $entityManager;
        $this->connection = $entityManager->getConnection();
    }
    
    public function getCurso(
        array $params
    ) {
        $sql = <<<SQL
        SELECT
            A.NRCURSO,
            A.NMCURSO,                 
            A.DSPROGRAMA,              
            A.CDESCOLARIDADE,
            A.DTULTATUCURSO,           
            A.NRORG,          
            A.DTINCLUSAO,
            A.DTULTATU,                
            A.NRORGINCLUSAO,           
            A.CDOPERINCLUSAO,
            A.NRORGULTATU,             
            A.CDOPERULTATU,            
            LPAD(QTCARGAHORARIA, 4, '0') AS QTCARGAHORARIA,
            A.DSOBJETIVOCURSO,         
            A.DSOBSERVACAOCURSO,       
            A.NRTIPOCURSO,
            A.NRCONFIGCURSO,
            B.NMTIPOCURSO,
            C.NMCONFIGCURSO,
            ESCO.DSESCOLARIDADE
        FROM
            GPE_CURSO         A
            LEFT JOIN GPE_TIPOCURSO     B ON ( A.NRTIPOCURSO = B.NRTIPOCURSO
                                           AND A.NRORG = B.NRORG )
            LEFT JOIN GPE_CONFIGCURSO   C ON ( A.NRCONFIGCURSO = C.NRCONFIGCURSO
                                             AND A.NRORG = C.NRORG )
            LEFT JOIN ESCOLARIDADE      ESCO ON ESCO.CDESCOLARIDADE = A.CDESCOLARIDADE
                                           AND ( ESCO.NRORG = A.NRORG
                                                 OR ESCO.NRORG = :P_NRORG_PADRAO )
        WHERE
            A.NRORG = :P_NRORG
        ORDER BY
            A.NRORG, A.NRCURSO
SQL;

        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);

        return $query->fetchAll();
    }
    
    public function getPerfilAcesso(
        array $params
    ) {
        $sql = <<<SQL
        SELECT
            *
        FROM
            PERFILACESSO
        WHERE
            ( NRORG = :P_NRORG
              OR NRORG = :P_NRORG_PADRAO )
        ORDER BY
            NMPERFILACESSO
SQL;

        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);

        return $query->fetchAll();
    }
    
    public function getMetodo(
        array $params
    ) {
        $sql = <<<SQL
        SELECT
            *
        FROM
            GPE_METODO_TRE
        WHERE
            ( NRORG = :P_NRORG
              OR NRORG = :P_NRORG_PADRAO )
        ORDER BY
            NRMETODOTRE
SQL;

        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);

        return $query->fetchAll();
    }
}